@@ -91,6 +91,7 @@ class RoaControllerTests(FantasticoUnitTestsCase):
         self.assertIsNotNone(response)
         self.assertEqual(200, response.status_code)
         self.assertEqual("application/json", response.content_type)
+        self._assert_cors_headers(response)
 
         self.assertIsNotNone(response.body)
 
@@ -104,6 +105,12 @@ class RoaControllerTests(FantasticoUnitTestsCase):
                                                                      sort_expr=expected_sort)
         self._model_facade.count_records.assert_called_once_with(filter_expr=expected_filter)
 
+    def _assert_cors_headers(self, response):
+        '''This method checks response for cors headers.'''
+
+        self.assertEqual("*", response.headers["Access-Control-Allow-Origin"])
+        self.assertEqual("OPTIONS,GET,POST,PUT,DELETE", response.headers["Access-Control-Allow-Methods"])
+
     def test_get_collection_default_values_emptyresult(self):
         '''This test case ensures get collection works as expected without any query parameters passed. It ensures
         empty items returns correct '''
@@ -195,6 +202,7 @@ class RoaControllerTests(FantasticoUnitTestsCase):
         self.assertIsNotNone(response)
         self.assertEqual(http_code, response.status_code)
         self.assertEqual("application/json", response.content_type)
+        self._assert_cors_headers(response)
 
         self.assertIsNotNone(response.body)
 
@@ -224,13 +232,8 @@ class RoaControllerTests(FantasticoUnitTestsCase):
 
         self._resources_registry.find_by_url.assert_called_once_with(url, float(version))
 
-    def test_roa_cors_support(self):
-        '''This test case ensures CORS is enabled on all ROA dynamic generated apis.'''
-
-        url = "/simple-resource"
-        version = "latest"
-
-        self._resources_registry.find_by_url = Mock(return_value=Mock())
+    def _test_roa_cors_template(self, url):
+        '''This method provides a template for testing ROA cors support.'''
 
         request = Mock()
         request.headers = {"Access-Control-Request-Headers": "header1,header2"}
@@ -249,22 +252,21 @@ class RoaControllerTests(FantasticoUnitTestsCase):
 
         self.assertEqual(0, len(response.body))
 
-        self._resources_registry.find_by_url.assert_called_once_with(url, version)
+
+    def test_roa_cors_support(self):
+        '''This test case ensures CORS is enabled on all ROA dynamic generated apis.'''
+
+        url = "/simple-resource"
+
+        self._test_roa_cors_template(url)
 
     def test_roa_cors_support_resourcenotfound(self):
-        '''This test case ensures an error is returned if an options http request is done for a resource which is not
+        '''This test case ensures no error is returned if an options http request is done for a resource which is not
         registered.'''
 
-        url = "/resource-not-found"
-        version = "1.0"
+        url = "/resource-not-found/213"
 
-        self._resources_registry.find_by_url = Mock(return_value=None)
-
-        response = self._controller.handle_resource_options(Mock(), version, url)
-
-        self._assert_resource_error(response, 404, 10000, version, url)
-
-        self._resources_registry.find_by_url.assert_called_once_with(url, float(version))
+        self._test_roa_cors_template(url)
 
     def test_create_item_noresourcefound(self):
         '''This test case ensures we can not add items to an inexistent resource.'''
@@ -353,6 +355,7 @@ class RoaControllerTests(FantasticoUnitTestsCase):
         self.assertIsNotNone(resource)
         self.assertEqual(201, response.status_code)
         self.assertEqual("application/json", response.content_type)
+        self._assert_cors_headers(response)
         self.assertEqual("0", response.headers["Content-Length"])
         self.assertEqual("/api/%s%s/%s" % (resource.version, resource.url, expected_id),
                          response.headers["Location"])
@@ -464,6 +467,7 @@ class RoaControllerTests(FantasticoUnitTestsCase):
         self.assertIsNotNone(response)
         self.assertEqual(200, response.status_code)
         self.assertEqual("application/json", response.content_type)
+        self._assert_cors_headers(response)
 
         self.assertIsNotNone(response.body)
         body = json.loads(response.body.decode())
@@ -666,6 +670,7 @@ class RoaControllerTests(FantasticoUnitTestsCase):
         self.assertIsNotNone(response)
         self.assertEqual(204, response.status_code)
         self.assertEqual("application/json", response.content_type)
+        self._assert_cors_headers(response)
         self.assertEqual("0", response.headers["Content-Length"])
 
         self.assertEqual(0, len(response.body))
@@ -767,6 +772,7 @@ class RoaControllerTests(FantasticoUnitTestsCase):
         self.assertIsNotNone(response)
         self.assertEqual(204, response.status_code)
         self.assertEqual("application/json", response.content_type)
+        self._assert_cors_headers(response)
         self.assertEqual("0", response.headers["Content-Length"])
 
         self.assertEqual(0, len(response.body))
