@@ -29,6 +29,17 @@ class FantasticoError(Exception):
     that at no moment errors will cause fantastico framework wsgi container to crash.
     '''
 
+    @property
+    def http_code(self):
+        '''This method returns the http code on which this exception is mapped.'''
+
+        return self._http_code
+
+    def __init__(self, msg=None, http_code=400):
+        super(FantasticoError, self).__init__(msg)
+
+        self._http_code = http_code
+
 class FantasticoControllerInvalidError(FantasticoError):
     '''This exception is raised whenever a method is decorated with
     :py:class:`fantastico.mvc.controller_decorators.Controller` and the number of arguments is not correct. Usually
@@ -87,7 +98,7 @@ class FantasticoDbError(FantasticoError):
     '''This exception is usually thrown when a database exception occurs. For one good example where this is used see
     :py:class:`fantastico.mvc.model_facade.ModelFacade`.'''
 
-class FantasticoDbNotFoundError(FantasticoError):
+class FantasticoDbNotFoundError(FantasticoDbError):
     '''This exception is usually thrown when an entity does not exist but we try to update it. For one good example where this is
     used see :py:class:`fantastico.mvc.model_facade.ModelFacade`.'''
 
